==> alphavibe-1.5.1.tar.gz: alphavibe-1.5.1/README.md <==
# alphavibe
alphavibe lets you write Python in the language of TikTok, memes, and group chats. No more `def`, `print`, or `for`. It’s `vibe`, `spitItOut`, and `zoom` now.
# 🍻 alphavibe

> Python, but coded by Gen Alpha. Slay like a sigma 💅

Finally, a python library that passes the vibe check 💯.

---

## ✨ Example

```python
from alphavibe import alphaRun

code = '''
bringIn math

vibe main():
    drip x in zoom range(5):
        spitItOut("Count:", x)
    bounce facts

main()
'''

alphaRun(code)
```

> Output:

```
Count: 0
Count: 1
Count: 2
Count: 3
Count: 4
```

---

## 🔤 Gen Alpha to Python Dictionary

| Gen Alpha        | Python     |
| ---------------- | ---------- |
| `vibe`           | `def`      |
| `sus`            | `if`       |
| `extraSus`       | `elif`     |
| `noCap`          | `else`     |
| `zoom`           | `for`      |
| `loopUntilBored` | `while`    |
| `spitItOut`      | `print`    |
| `bounce`         | `return`   |
| `facts`          | `True`     |
| `nah`            | `False`    |
| `ghost`          | `None`     |
| `&also`          | `and`      |
| `maybe`          | `or`       |
| `that`           | `not`      |
| `among`          | `in`       |
| `sameVibe`       | `is`       |
| `squad`          | `class`    |
| `bringIn`        | `import`   |
| `aka`            | `as`       |
| `cook`           | `try`      |
| `catchFlop`      | `except`   |
| `throwDrama`     | `raise`    |
| `lockedIn`       | `with`     |
| `multiSlay`      | `async`    |
| `holdUp`         | `await`    |
| `spillTea`       | `input`    |
| `vibeCheck`      | `len`      |
| `slay`           | `exit`     |
| `bet`            | `break`    |
| `sussy`          | `continue` |
| `sussOut`        | `pass`     |
| `alpha`          | `def main` |
| `beta`           | `def __init__` |
| `sigma`          | `def __str__` |
| `glowUp`         | `global`   |
| `lowKey`         | `nonlocal` |
| `bigMood`        | `True`     |
| `noMood`         | `False`    |
| `chill`          | `pass`     |
| `hype`           | `assert`   |
| `drip`           | `yield`    |
| `flex`           | `lambda`   |
| `squadGoals`     | `super`    |
| `mainCharacter`  | `__name__` |
| `plotTwist`      | `__init__` |
| `endGame`        | `__del__`  |
| `bigBrain`       | `isinstance` |
| `sameEnergy`     | `issubclass` |
| `deepDive`       | `open`     |
| `teaSpill`       | `print`    |
| `screenshot`     | `repr`     |
| `vibeShift`      | `set`      |
| `squadUp`        | `dict`     |
| `squadList`      | `list`     |
| `squadGoalsList` | `tuple`    |
| `squadVibes`     | `set`      |
| `squadKeys`      | `keys`     |
| `squadValues`    | `values`   |
| `squadItems`     | `items`    |
| `squadPop`       | `pop`      |
| `squadAdd`       | `add`      |
| `squadRemove`    | `remove`   |
| `squadClear`     | `clear`    |
| `squadUpdate`    | `update`   |
| `bigFlex`        | `map`      |
| `bigZoom`        | `filter`   |
| `bigDrip`        | `reduce`   |
| `bigBet`         | `enumerate` |
| `bigTea`         | `zip`      |
| `bigVibes`       | `sorted`   |
| `bigChill`       | `reversed` |
| `bigGlowUp`      | `globals`  |
| `bigLowKey`      | `locals`   |
| `bigPlotTwist`   | `staticmethod` |
| `bigSquadGoals`  | `classmethod` |
| `bigMainCharacter` | `__main__` |
| `bigFacts`       | `True`     |
| `bigNah`         | `False`    |
| `bigGhost`       | `None`     |
| `bigCook`        | `try`      |
| `bigCatchFlop`   | `except`   |
| `bigThrowDrama`  | `raise`    |
| `bigLockedIn`    | `with`     |
| `bigMultiSlay`   | `async`    |
| `bigHoldUp`      | `await`    |
| `bigSussy`       | `continue` |
| `bigBetBet`      | `break`    |
| `bigSussOut`     | `pass`     |

---

## 🚫 Anti-Boomer Filter

We don’t mess with crusty old keywords. If you try to write:

```python
def hello():
    print("hi")
```

You'll get roasted with:

```
🚫 Boomer code at line 1: def found.
💡 Did you mean vibe instead?
```

Boomer-proofed for maximum drip 😤

---

## 📦 Installation

```bash
pip install alphavibe
```

---

## 🛠 How to Use

```python
from alphavibe import alphaRun

code = """
vibe hello():
    spitItOut("heyyy")
"""

alphaRun(code)
```

---

## 💡 Pro Tip

Make your `.py` files full of Gen Alpha code and call `alphaRun(open("myfile.py").read())` to run them like a sigma coder 💪.

---

## 📣 Spread the Vibe

---

---

## 🧑‍💻 Author

Made by Trương Minh Huy (a.k.a Louis)
Contact: 0902555923 (+84 VN)

==> alphavibe-2.0.1.tar.gz: alphavibe-2.0.1/README.md <==
# alphavibe
alphavibe lets you write Python in the language of TikTok, memes, and group chats. No more `def`, `print`, or `for`. It’s `vibe`, `spitItOut`, and `zoom` now.
# 🍻 alphavibe

> Python, but coded by Gen Alpha. Slay like a sigma 💅

Finally, a python library that passes the vibe check 💯.

---

## ✨ Example

```python
from alphavibe import alphaRun

code = '''
bringIn math

vibe main():
    drip x in zoom range(5):
        spitItOut("Count:", x)
    bounce facts

main()
'''

alphaRun(code)
```

> Output:

```
Count: 0
Count: 1
Count: 2
Count: 3
Count: 4
```

---

## 🔤 Gen Alpha to Python Dictionary

| Gen Alpha        | Python     |
| ---------------- | ---------- |
| `vibe`           | `def`      |
| `sus`            | `if`       |
| `extraSus`       | `elif`     |
| `noCap`          | `else`     |
| `zoom`           | `for`      |
| `loopUntilBored` | `while`    |
| `spitItOut`      | `print`    |
| `bounce`         | `return`   |
| `facts`          | `True`     |
| `nah`            | `False`    |
| `ghost`          | `None`     |
| `&also`          | `and`      |
| `maybe`          | `or`       |
| `that`           | `not`      |
| `among`          | `in`       |
| `sameVibe`       | `is`       |
| `squad`          | `class`    |
| `bringIn`        | `import`   |
| `aka`            | `as`       |
| `cook`           | `try`      |
| `catchFlop`      | `except`   |
| `throwDrama`     | `raise`    |
| `lockedIn`       | `with`     |
| `multiSlay`      | `async`    |
| `holdUp`         | `await`    |
| `spillTea`       | `input`    |
| `vibeCheck`      | `len`      |
| `slay`           | `exit`     |
| `bet`            | `break`    |
| `sussy`          | `continue` |
| `sussOut`        | `pass`     |
| `alpha`          | `def main` |
| `beta`           | `def __init__` |
| `sigma`          | `def __str__` |
| `glowUp`         | `global`   |
| `lowKey`         | `nonlocal` |
| `bigMood`        | `True`     |
| `noMood`         | `False`    |
| `chill`          | `pass`     |
| `hype`           | `assert`   |
| `drip`           | `yield`    |
| `flex`           | `lambda`   |
| `squadGoals`     | `super`    |
| `mainCharacter`  | `__name__` |
| `plotTwist`      | `__init__` |
| `endGame`        | `__del__`  |
| `bigBrain`       | `isinstance` |
| `sameEnergy`     | `issubclass` |
| `deepDive`       | `open`     |
| `teaSpill`       | `print`    |
| `screenshot`     | `repr`     |
| `vibeShift`      | `set`      |
| `squadUp`        | `dict`     |
| `squadList`      | `list`     |
| `squadGoalsList` | `tuple`    |
| `squadVibes`     | `set`      |
| `squadKeys`      | `keys`     |
| `squadValues`    | `values`   |
| `squadItems`     | `items`    |
| `squadPop`       | `pop`      |
| `squadAdd`       | `add`      |
| `squadRemove`    | `remove`   |
| `squadClear`     | `clear`    |
| `squadUpdate`    | `update`   |
| `bigFlex`        | `map`      |
| `bigZoom`        | `filter`   |
| `bigDrip`        | `reduce`   |
| `bigBet`         | `enumerate` |
| `bigTea`         | `zip`      |
| `bigVibes`       | `sorted`   |
| `bigChill`       | `reversed` |
| `bigGlowUp`      | `globals`  |
| `bigLowKey`      | `locals`   |
| `bigPlotTwist`   | `staticmethod` |
| `bigSquadGoals`  | `classmethod` |
| `bigMainCharacter` | `__main__` |
| `bigFacts`       | `True`     |
| `bigNah`         | `False`    |
| `bigGhost`       | `None`     |
| `bigCook`        | `try`      |
| `bigCatchFlop`   | `except`   |
| `bigThrowDrama`  | `raise`    |
| `bigLockedIn`    | `with`     |
| `bigMultiSlay`   | `async`    |
| `bigHoldUp`      | `await`    |
| `bigSussy`       | `continue` |
| `bigBetBet`      | `break`    |
| `bigSussOut`     | `pass`     |

---

## 🚫 Anti-Boomer Filter

We don’t mess with crusty old keywords. If you try to write:

```python
def hello():
    print("hi")
```

You'll get roasted with a warning

Boomer-proofed for maximum drip 😤

---

## 📦 Installation

```bash
pip install alphavibe
```

---

## 🛠 How to Use

```python
from alphavibe import alphaRun

code = """
vibe hello():
    spitItOut("heyyy")
"""

alphaRun(code)
```

---

## 💡 Pro Tip

Make your `.py` files full of Gen Alpha code and call `alphaRun(open("myfile.py").read())` to run them like a sigma coder 💪.

---

## 📣 Spread the Vibe

---

---

## 🧑‍💻 Author

Made by Trương Minh Huy (a.k.a Louis)
Contact: 0902555923 (+84 VN)
